( cd usr/java ; rm -rf jre )
( cd usr/java ; ln -sf jre1.6.0 jre )
( cd usr/java/jre1.6.0/man ; rm -rf ja )
( cd usr/java/jre1.6.0/man ; ln -sf ja_JP.eucJP ja )
( cd usr/java/jre1.6.0/lib/i386/client ; rm -rf libjsig.so )
( cd usr/java/jre1.6.0/lib/i386/client ; ln -sf ../libjsig.so libjsig.so )
( cd usr/java/jre1.6.0/lib/i386/server ; rm -rf libjsig.so )
( cd usr/java/jre1.6.0/lib/i386/server ; ln -sf ../libjsig.so libjsig.so )
( cd usr/java/jre1.6.0/bin ; rm -rf ControlPanel )
( cd usr/java/jre1.6.0/bin ; ln -sf ./jcontrol ControlPanel )
( cd usr/java/jre1.6.0/javaws ; rm -rf javaws )
( cd usr/java/jre1.6.0/javaws ; ln -sf ../bin/javaws javaws )
